@@ -9,9 +9,10 @@
 circlin.cor <- function(theta, x, rads = FALSE) {
   ## theta is a angular variable in degrees by default
   ## x is euclidean variable or a matrix containing euclidean variables
+
   x <- as.matrix(x)
   n <- length(theta)  ## sample size
-  if (rads == F)  theta <- theta * pi/180
+  if ( rads == FALSE )  theta <- theta * pi/180
   costheta <- cos(theta)
   sintheta <- sin(theta)
 
@@ -19,10 +20,12 @@ circlin.cor <- function(theta, x, rads = FALSE) {
   rxs <- as.numeric( cor(sintheta, x) )  ## sin(theta) and x correlation
   rcs <- cor(costheta, sintheta)  ## cos(theta) and sin(theta) correlation
   R2xt <- (rxc^2 + rxs^2 - 2 * rxc * rxs * rcs)/(1 - rcs^2)
+
   ## linear-circular correlation
   Ft <- (n - 3) * R2xt/(1 - R2xt)  ## F-test statistic value
   pvalue <- pf(Ft, 2, n - 3, lower.tail = FALSE)
   res <- cbind(R2xt, pvalue)
   colnames(res) <- c('R-squared', 'p-value')
   res
+
 }
