@@ -33,16 +33,17 @@ knn.reg <- function(xnew, y, x, k = 5, res = "eucl", type = "euclidean", estim =
     disa <- acos(dis)
 
   } else if ( type =="euclidean" || type == "manhattan" ) {
-    m <- colMeans(x)
-    s <- apply(x, 2, sd)
-    x <- scale(x)[1:n, ]  ## standardize the independent variables
+    m <- as.vector( Rfast::colmeans(x) )
+    s <- as.vector( Rfast::colVars(x, std = TRUE) )
+    x <- ( t(x) - m ) / s ## standardize the independent variables
+    x <- t(x)
 
     if (p == 1) {
       xnew <-as.vector(xnew)
       xnew <- (xnew - m) / s
     } else if ( p > 1 ) {
-      s <- diag(1/s)
-      xnew <- ( xnew - rep(m, rep(nu, p)) ) %*% s  ## standardize the xnew values
+      xnew <- ( t(xnew) - m ) / s  ## standardize the xnew values
+      xnew <- t(xnew)
     }
 
     ## calculates distance matrix for the Euclidean data
@@ -56,17 +57,22 @@ knn.reg <- function(xnew, y, x, k = 5, res = "eucl", type = "euclidean", estim =
     disa <- matrix( 0, nu, n )
 
     if (type == "euclidean") {
-      Ip <- diag(p)
-      for (i in 1:nu) {
-        disa[i, ] <- as.vector( sqrt( mahalanobis(x, xnew[i, ], Ip, inverted = TRUE) ) )
-      }
+       z <- t(x)
+
+       for (i in 1:nu) {
+         zz <- z - xnew[i, ]
+         disa[i, ] <- sqrt( colSums( zz^2 ) )
+       }
 
     } else if (type == "manhattan") {
+      z <- t(x)
+
       for (i in 1:nu) {
-        a <- t(x) - xnew[i, ]
-        disa[i, ] <- colSums( abs(a) )
+        a <- z - xnew[i, ]
+        disa[i, ] <- as.vector( Rfast::colsums( abs(a) ) )
       }
     }
+
   }
 
   ina <- 1:n
@@ -78,7 +84,7 @@ knn.reg <- function(xnew, y, x, k = 5, res = "eucl", type = "euclidean", estim =
       qan <- xa[order(xa[, 2]), ]
       a <- qan[1:k, 1]
       yb <- as.matrix( y[a, ] )
-      est[i, ] <- colMeans( yb )
+      est[i, ] <- as.vector( Rfast::colmeans( yb ) )
     }
 
   } else if (estim == "harmonic") {
@@ -87,12 +93,12 @@ knn.reg <- function(xnew, y, x, k = 5, res = "eucl", type = "euclidean", estim =
       qan <- xa[order(xa[, 2]), ]
       a <- qan[1:k, 1]
       yb <- as.matrix( y[a, ] )
-      est[i, ] <- k / colSums( yb )
+      est[i, ] <- k / as.vector( Rfast::colsums( yb ) )
     }
   }
 
   if (res == "spher") {
-    y <- y /sqrt( rowSums(y^2) )
+    y <- y / sqrt( rowSums(y^2) )
   } else  y <- y
 
   if ( is.null(colnames(y)) ) {
