@@ -30,9 +30,10 @@ rbingham <- function(n, A) {
   lam.full <- c(lam, 0)
   qa <- length(lam.full)
   mu <- numeric(qa)
-  A <- diag(lam.full)
-  SigACG.inv <- diag(qa) + 2 * A
-  SigACG <- solve(SigACG.inv)
+
+  sigacginv <- 1 + 2 * lam.full
+  SigACG <- diag( 1 / ( 1 + 2 * lam.full ) )
+
   Ntry <- 0
 
   while (nsamp < n) {
@@ -40,8 +41,8 @@ rbingham <- function(n, A) {
     while (x.samp == FALSE) {
       yp <- MASS::mvrnorm(n = 1, mu = mu, Sigma = SigACG)
       y <- yp / sqrt( sum( yp^2 ) )
-      lratio <-  - mahalanobis(y, mu, A, inverted = TRUE) - qa/2 * log(qa) +
-        0.5 * (qa - 1) + qa/2 * log( mahalanobis( y, mu, SigACG.inv, inverted = TRUE ) )
+      lratio <-  - sum( y^2 * lam.full ) - qa/2 * log(qa) +
+        0.5 * (qa - 1) + qa/2 * log( sum(y^2 * sigacginv ) )
       if ( log(runif(1) ) < lratio) {
         X <- c(X, y)
         x.samp <- TRUE
