@@ -8,29 +8,31 @@
 
 spher.cor <- function(x, y) {
   ## x and y are two (hyper-)spherical variables
-
+  
   x <- as.matrix(x)
   y <- as.matrix(y)
   x <- x / sqrt( rowSums(x^2) )
   y <- y / sqrt( rowSums(y^2) )
-
-  stand <- function(x) x - mean(x)
+  
   p <- ncol(x)  ## dimension of x
   q <- ncol(y)  ## dimension of y
-  x <- apply(x, 2, stand)  ## subtract the mean
-  y <- apply(y, 2, stand)  ## subtract the mean
   n <- nrow(x)  ## sample size
+  x <-  t(x) - as.vector( Rfast::colmeans(x) )    ## subtract the mean
+  y <-  t(y) - as.vector(Rfast::colmeans(y) )  ## subtract the mean
 
-  s11 <- crossprod(x) / n
-  s12 <- crossprod( x, y ) / n
+  s11 <- tcrossprod(x) / n
+  s12 <- tcrossprod( x, y ) / n
   s21 <- t( s12 )
-  s22 <- crossprod(y) / n
-
-  rsq <- sum( diag(solve(s11, s12) %*% solve(s22, s21) ) )
+  s22 <- tcrossprod(y) / n
+  
+  a1 <- solve(s11, s12)
+  a2 <- solve(s22, s21) 
+  rsq <- sum( t(a1) * a2)
   test <- n * rsq
-  pvalue <- 1 - pchisq(test, p * q)
+  pvalue <- pchisq(test, p * q, lower.tail = FALSE)
   res <- c(rsq, pvalue)
-
+  
   names(res) <- c('R-squared', 'p-value')
   res
-}
+  
+}
\ No newline at end of file
